/*
* This computer program is the confidential information and proprietary
* trade secret of Cisco Systems, Inc.  Possessions and use of this
* program must conform strictly to the license agreement between the user
* and Cisco Systems, Inc., and receipt or possession does not convey
* any rights to divulge, reproduce, or allow others to use this program
* without specific written authorization of Cisco Systems, Inc.
*
*      Copyright (c) 2015 Cisco Systems, Inc.
*      All rights reserved.
*/

define([
	"dojo/_base/declare",
	"xwt/widget/LoginPage",
	"dojo/dom-construct",
	"dojo/_base/array",
	"dojo/_base/lang",
	"dojo/i18n",
	"wcs/widget/InstalledUpdatesPopover",
	"xwt/widget/_i18nMixin"
], function(declare, login, domConstruct, array, lang, i18n, InstalledUpdatesPopover, _i18nMixin){
	
	var NCS = lang.getObject("NCS");
	var localStorage = lang.getObject("localStorage");
	var location = lang.getObject("location");
	
	return declare("wcs.widget.NCSLoginPage", [login, xwt.widget._i18nMixin], {
		isCLuster: false,
		nbifailed: "",
		vdfailed: "",	
		lockfailed: "",
		authfailserver:"",
		accessChallenge: "",
		sessionlimit:"",
		ocspLoginFailure:"",
		installedUpdatesTitle: "",
		i18nPackageName: "xmp",
		i18nBundleName: "xmp",
		//wcsEnableAutocomplete: Boolean
		// if it is true enable autocomplete otherwise if false disables autocomplete
		wcsEnableAutocomplete: true,
		allowCopyPastePassword: true,
		displayMessageByID: function(/*String*/id) {
			if(id && id==="nbi_failed"){
				this.showAlertBox("warning", this.nbifailed);
			}
			else if(id && id==="vd_failed"){
				this.showAlertBox("warning", this.vdfailed);
			}
			else if(id && id==="lock_failed"){
				this.showAlertBox("warning", this.lockfailed);
			}
			else if(id && id==="auth_failed_server"){
			   this.showAlertBox("warning", this.authfailserver);
			}
			else if(id && id==="auth_access_challenge"){
			   this.showAlertBox("warning", this.accessChallenge);
			}
			else if(id && id=="session_limit"){
			   this.showAlertBox("warning", this.sessionlimit);
			}else if(id && id=="ocspLogin_Failure"){
			   this.showAlertBox("warning", this.ocspLoginFailure);
			}
			else{
					this.inherited(arguments);
			}
	},

	postMixInProperties: function(){
		this.informationText = this.informationText.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;').replace(/'/g, '&apos;');
		this.inherited(arguments);
	 },
	
	postCreate: function(){
		this.inherited(arguments);
		if(localStorage){
			// If localStorage is not supported by the browser, we cannot handle multiple language support.
			this.addLanguageNode();
		}
		this.addInstalledUpdateWidget();
	},
	
	startup: function(){
		this.inherited(arguments);
		if(!this.wcsEnableAutocomplete){
			dojo.attr(this.usernameAP.textbox, "autocomplete", "off");
		}
		 this.sessionlimit = this.getI18nLabel("sessionLimit","You have exceeded the number of active sessions allowed for this user. Log out of one active session, or wait for up to 30 minutes and log in again.");
		this._i18nMessages["session_limit"]= this.sessionlimit;
		this._i18nMessages["nbi_failed"]= this.nbifailed;
		this._i18nMessages["vd_failed"]= this.vdfailed;
		this._i18nMessages["lock_failed"]= this.lockfailed;
		this._i18nMessages["auth_failed_server"]= this.authfailserver;
		this._i18nMessages["auth_access_challenge"]= this.accessChallenge;
		this._i18nMessages["ocspLogin_Failure"]= this.ocspLoginFailure;
	},

	addLanguageNode: function(){
		if (this.isCLuster) {
			return;
		}
		var supportedLanguage = [
			{label: "English", locale: "en"},
			{label: "日本語", locale: "ja"},
			{label: "한국어", locale: "ko"}
		];
		var i18n = dojo.i18n["getLocalization"]("xmp","xmp");
		var node = domConstruct.create("div", {"class":"languageNode"}, this.loginFieldsNode, "after");
		var labelNode = domConstruct.create("div", {"class": "dijitInline langLabel", innerHTML: i18n.languages}, node);
		array.forEach(supportedLanguage, function(langObj, idx){
			if(idx !== 0){
				domConstruct.create("div", {"class": "dijitInline itemSeperator", innerHTML: " | "}, node);
			}
			var nodeClass = "dijitInline xwtLinkCSS";
			if(NCS.CONSTANTS.locale === langObj.locale){
				nodeClass += " isSelected";
			}
			domConstruct.create("div", {"class": nodeClass, innerHTML: langObj.label, onclick: lang.hitch(this, "onLocaleClick", langObj)}, node);
		}, this);
	},
	
	onLocaleClick: function(langObj){
		if(langObj.locale === NCS.CONSTANTS.locale){
			return;
		}
		localStorage.setItem("userSelectedLocale", langObj.locale);
		location.reload();
	},
	
	addInstalledUpdateWidget: function(){
		if(this.installedUpdatesWidget || this.isCLuster){
			return;
		}
		
                this.installedUpdatesTitle = this.getI18nLabel("installedUpdates","Installed Updates");
		this.installedUpdatesWidget = new InstalledUpdatesPopover({installedUpdatesTitle: this.installedUpdatesTitle}, domConstruct.create("div", {}, this.customElements));
	},
	
	/***
	The supported browser call is copied from XWT to PI .
	As it specific to PI - which does not support FF - but supports ESR and there is no API to recoginze as ESR.
	Sanjay Shrivastav  from WAP team owns this

	**/

	isBrowserSupported: function(){
			if(!this.checkBrowser){ return;}
			xwt.supportedBrowser = this.supportedBrowserList;

			if(!this.isSupportedBrowser()){
				dojo.style(this.messageBoxAP, {
					"display": "block"
				});
				dojo.style(this.browserNotification, {
					"display": "block"
				});
			}
	 },

	isSupportedBrowser: function (){

		var browserList = dojo.config.supportedBrowser || xwt.supportedBrowser;
		for(var b in browserList){
			var arr = browserList[b];
			if(b=='ESR'){
			   b='FF';
			}
			if(dojo.isArray(arr)){
				for(var arrVal in arr){
					var browserVersion = arr[arrVal].toString();
					// This condition is to check if user mentioned supported versions like '3+' instead of 3,4,5,6,...
					if(browserVersion.indexOf("+") != -1){
						var _browserVersion = browserVersion.substring(0,browserVersion.indexOf("+"));
						if(Math.floor(dojo['is' + b]) >= parseInt(_browserVersion)){
							return true;
						}
					}
					
				}
				if(dojo.indexOf(arr, Math.floor(dojo['is' + b])) != -1){
					return true;
				}
			}else{
				if(dojo['is' + b]){
					return true;
				}
			}
			
		}

		return false;
	}

	});
});
